@@ -35,7 +35,7 @@
     job_memsize <- .jobs_memsize(
         job_size = .block_size(block = block_size),
         npaths = length(probs_cubes) * nrow(base_cube) *
-            length(sits_labels(base_cube)),
+            length(.cube_labels(base_cube)),
         nbytes = 8,
         proc_bloat = .conf("processing_bloat_cpu")
     )
@@ -58,7 +58,7 @@
     on.exit(.parallel_stop(), add = TRUE)
     # Call the combine method
     # Process each tile sequentially
-    probs_cube <- purrr::map_dfr(seq_len(nrow(base_cube)), function(i) {
+    probs_cube <- .map_dfr(seq_len(nrow(base_cube)), function(i) {
         probs_tile <- .comb_tiles(
             probs_tiles = lapply(probs_cubes, .slice_dfr, i),
             uncert_tiles = lapply(uncert_cubes, .slice_dfr, i),
@@ -222,15 +222,11 @@
         input_pixels <- nrow(values[[1]])
         # Combine by average
         values <- weighted_probs(values, weights)
+        # get the number of labels
+        n_labels <- length(.cube_labels(cubes[[1]]))
         # Are the results consistent with the data input?
         .check_processed_values(values, input_pixels)
-        .check_that(
-            ncol(values) == length(sits_labels(cubes[[1]])),
-            msg = paste(
-                "number of columns of processed matrix is different",
-                "from the number of cube labels"
-            )
-        )
+        .check_processed_labels(values, n_labels)
         # Return values
         values
     }
@@ -251,15 +247,11 @@
         input_pixels <- nrow(values[[1]])
         # Combine by average
         values <- weighted_uncert_probs(values, uncert_values)
+        # get the number of labels
+        n_labels <- length(.cube_labels(cubes[[1]]))
         # Are the results consistent with the data input?
         .check_processed_values(values, input_pixels)
-        .check_that(
-            ncol(values) == length(sits_labels(cubes[[1]])),
-            msg = paste(
-                "number of columns of processed matrix is different",
-                "from the number of cube labels"
-            )
-        )
+        .check_processed_labels(values, n_labels)
         # Return values
         values
     }
