@@ -64,7 +64,7 @@
     }
 
     # how many different labels are there?
-    labels <- sits_labels(data)
+    labels <- .samples_labels(data)
 
     label_plots <- labels |>
         purrr::map(function(l) {
@@ -74,9 +74,9 @@
             # how many time series are to be plotted?
             number <- nrow(data2)
             # what are the band names?
-            bands <- sits_bands(data2)
+            bands <- .samples_bands(data2, include_base = FALSE)
             # what are the reference dates?
-            ref_dates <- sits_timeline(data2)
+            ref_dates <- .samples_timeline(data2)
             # align all time series to the same dates
             data2 <- .tibble_align_dates(data2, ref_dates)
 
@@ -161,8 +161,7 @@
         group = .data[["variable"]]
     )) +
         ggplot2::geom_line(ggplot2::aes(color = .data[["variable"]])) +
-        ggplot2::labs(title = plot_title) +
-        ggplot2::scale_fill_manual(palette = colors)
+        ggplot2::labs(title = plot_title)
     return(g)
 }
 #' @title Plot one time series with NAs using ggplot
