@@ -168,6 +168,7 @@
 #' locations are guaranteed to be separated by a certain number of pixels.
 #'
 #' @param r_obj           A raster object.
+#' @param block           Individual block that will be processed.
 #' @param band            A numeric band index used to read bricks.
 #' @param n               Number of values to extract.
 #' @param sampling_window Window size to collect a point (in pixels).
@@ -175,6 +176,7 @@
 #' @return                A point `tibble` object.
 #'
 .raster_get_top_values <- function(r_obj,
+                                   block,
                                    band,
                                    n,
                                    sampling_window) {
@@ -182,18 +184,24 @@
     # Get top values
     # filter by median to avoid borders
     # Process window
-    values <- .raster_get_values(r_obj)
+    values <- .raster_get_values(
+        r_obj,
+        row = block[["row"]],
+        col = block[["col"]],
+        nrows = block[["nrows"]],
+        ncols = block[["ncols"]]
+    )
     values <- C_kernel_median(
         x = values,
-        ncols = .raster_ncols(r_obj),
-        nrows = .raster_nrows(r_obj),
+        nrows = block[["nrows"]],
+        ncols = block[["ncols"]],
         band = 0,
         window_size = sampling_window
     )
     samples_tb <- C_max_sampling(
         x = values,
-        nrows = .raster_nrows(r_obj),
-        ncols = .raster_ncols(r_obj),
+        nrows = block[["nrows"]],
+        ncols = block[["ncols"]],
         window_size = sampling_window
     )
     samples_tb <- dplyr::slice_max(
@@ -757,8 +765,8 @@
                              missing_value) {
     # Create an empty image template
     gdalUtilities::gdal_translate(
-        src_dataset = .file_normalize(base_file),
-        dst_dataset = .file_normalize(out_file),
+        src_dataset = .file_path_expand(base_file),
+        dst_dataset = .file_path_expand(out_file),
         ot = .raster_gdal_datatype(data_type),
         of = "GTiff",
         b = rep(1, nlayers),
@@ -807,13 +815,13 @@
     # for each file merge blocks
     for (i in seq_along(out_files)) {
         # Expand paths for out_file
-        out_file <- .file_normalize(out_files[[i]])
+        out_file <- .file_path_expand(out_files[[i]])
         # Check if out_file does not exist
         .check_that(!file.exists(out_file))
         # Get file paths
         merge_files <- purrr::map_chr(block_files, `[[`, i)
         # Expand paths for block_files
-        merge_files <- .file_normalize(merge_files)
+        merge_files <- .file_path_expand(merge_files)
         # check if block_files length is at least one
         .check_file(
             x = merge_files,
@@ -836,9 +844,10 @@
                             srcfile = merge_files,
                             dstfile = out_file,
                             wo = paste0("NUM_THREADS=", multicores),
+                            co = .conf("gdal_creation_options"),
                             multi = TRUE,
                             q = TRUE,
-                            overwrite = FALSE
+                            overwrite = TRUE
                         )
                     )
                 },
