@@ -172,7 +172,7 @@
     # Define smooth function
     smooth_fn <- function(values, block) {
         # Check values length
-        n_input_pixels <- nrow(values)
+        input_pixels <- nrow(values)
         # Compute logit
         values <- log(values / (rowSums(values) - values))
         # Process Bayesian
@@ -187,7 +187,7 @@
         # Compute inverse logit
         values <- exp(values) / (exp(values) + 1)
         # Are the results consistent with the data input?
-        .check_processed_values(values, n_input_pixels)
+        .check_processed_values(values, input_pixels)
         # Return values
         values
     }
