@@ -65,9 +65,18 @@ NULL
             },
             .default = FALSE
         )
+        # is this a collection of DEM data ?
+        dem_cube <- .try({
+            .conf("sources", source, "collections", collection, "dem_cube")
+            },
+            .default = FALSE
+        )
         # if this is a SAR collection, add "sar_cube" to the class
         if (sar_cube)
             class(source) <- c("sar_cube", class(source))
+        # if this is a DEM collection, add "dem_cube" to the class
+        if (dem_cube)
+            class(source) <- c("dem_cube", class(source))
         # add a class combining source and collection
         class_source_col <- paste(classes[[1]], tolower(collection), sep = "_")
         class(source) <- unique(c(class_source_col, class(source)))
@@ -728,7 +737,103 @@ NULL
     }
     return(invisible(NULL))
 }
+#' @rdname .source_collection_class_labels
+#' @noRd
+#' @description \code{.source_collection_class_labels()} fixes the
+#' labels defined in a categorical cube loaded from an external source.
+#'
+#' @return \code{.source_collection_class_labels()} returns the input tile
+#' with the labels fixed.
+#'
+.source_collection_class_labels <- function(source, collection, tile) {
+    .check_set_caller(".source_collection_class_labels")
+    # define if the given collection is categorical
+    is_class_cube <- .try(
+        .conf(
+            "sources", source, "collections", collection, "class_cube"
+        ),
+        .default = FALSE
+    )
+    # if categorical, extract labels
+    if (is_class_cube) {
+        bands <- .conf("sources", source, "collections", collection)
+        bands <- names(bands[["bands"]])
 
+        # extract labels associated with bands
+        labels <- purrr::map(bands, function(band) {
+            .conf(
+                "sources", source,
+                "collections", collection,
+                "bands", band,
+                "values"
+            )
+        })
+
+        # prepare labels
+        labels <- unlist(labels)
+
+        # add labels to tile
+        tile[["labels"]] <- list(labels)
+    }
+    # return!
+    tile
+}
+#' @rdname .source_collection_class_tile_dates
+#' @noRd
+#' @description \code{.source_collection_class_tile_dates()} fixes the
+#' dates defined in a categorical cube loaded from an external source.
+#'
+#' @return \code{.source_collection_class_tile_dates()} returns the input tile
+#' with the dates fixed.
+#'
+.source_collection_class_tile_dates  <- function(source, collection, tile) {
+    .check_set_caller(".source_collection_class_tile_dates")
+    # define if the given collection is categorical
+    is_class_cube <- .try(
+        .conf(
+            "sources", source, "collections", collection, "class_cube"
+        ),
+        .default = FALSE
+    )
+    # class cube from source collection doesn't have multiple dates
+    if (is_class_cube) {
+        tile_date <- tile[["file_info"]][[1]][["date"]]
+
+        # create start and end dates
+        tile[["file_info"]][[1]][["start_date"]] <- tile_date
+        tile[["file_info"]][[1]][["end_date"]] <- tile_date
+
+        # delete date
+        tile[["file_info"]][[1]][["date"]] <- NULL
+    }
+    # return!
+    tile
+}
+#' @rdname .source_collection_class_tile_band
+#' @noRd
+#' @description \code{.source_collection_class_tile_band()} fixes the
+#' bands defined in a categorical cube loaded from an external source.
+#'
+#' @return \code{.source_collection_class_tile_band()} returns the input tile
+#' with the bands fixed.
+#'
+.source_collection_class_tile_band <- function(source, collection, tile) {
+    .check_set_caller(".source_collection_class_tile_band")
+    # define if the given collection is categorical
+    is_class_cube <- .try(
+        .conf(
+            "sources", source, "collections", collection, "class_cube"
+        ),
+        .default = FALSE
+    )
+    # bands from stac are defined in upper case. To avoid modifications in the
+    # config-api, the bands are renamed to their lowercase version.
+    if (is_class_cube) {
+        .tile_bands(tile) <- stringr::str_to_lower(.tile_bands(tile))
+    }
+    # return!
+    tile
+}
 #' @title Functions to instantiate a new cube from a source
 #' @name .source_cube
 #' @keywords internal
@@ -778,7 +883,7 @@ NULL
 #' @return \code{.source_item_get_date()} returns a \code{Date} value.
 #'
 .source_item_get_date <- function(source, item, ..., collection = NULL) {
-    source <- .source_new(source)
+    source <- .source_new(source, collection)
     UseMethod(".source_item_get_date", source)
 }
 
