@@ -117,7 +117,7 @@
     tiles <- unique(raster_items[["tile"]])
 
     # make a cube for each tile (rows)
-    cube <- purrr::map_dfr(tiles, function(tile) {
+    cube <- .map_dfr(tiles, function(tile) {
         # filter tile
         items_tile <- dplyr::filter(raster_items, .data[["tile"]] == !!tile)
         # create result cube
@@ -131,12 +131,18 @@
             return(tile_cube)
         }
         # create EO cube
-        .local_cube_items_cube(
+        tile_cube <- .local_cube_items_cube(
             source = source,
             collection = collection,
             items = items_tile
         )
+        # return!
+        tile_cube
     })
+
+    # handle class cubes from external sources
+    cube <- .local_cube_handle_class_cube(source, collection, cube)
+
     if (.has(vector_items)) {
         cube <- .local_cube_include_vector_info(cube, vector_items)
     }
@@ -765,6 +771,32 @@
     )
     return(cube_tile)
 }
+
+#' @title Handle details related to class cubes from external sources.
+#' @keywords internal
+#' @noRd
+#' @param source       Data source (one of \code{"AWS"}, \code{"BDC"},
+#' \code{"DEAFRICA"}, \code{"MPC"}, \code{"USGS"}).
+#' @param collection   Image collection in data source (To find out
+#'  the supported collections, use \code{\link{sits_list_collections}()}).
+#' @param cube        Data cube object.
+#' @return  Data cube tibble
+.local_cube_handle_class_cube <- function(source, collection, cube) {
+    # set caller to show in errors
+    .check_set_caller(".local_cube_handle_class_cube")
+    # process cube
+    slider::slide_dfr(cube, function(tile) {
+        # handle dates
+        tile <- .source_collection_class_tile_dates(source, collection, tile)
+        # handle bands
+        tile <- .source_collection_class_tile_band(source, collection, tile)
+        # handle labels
+        tile <- .source_collection_class_labels(source, collection, tile)
+        # return!
+        tile
+    })
+}
+
 .local_cube_include_vector_info <- function(cube, vector_items) {
     cube <- slider::slide_dfr(cube, function(tile) {
         item <- dplyr::filter(vector_items, .data[["tile"]] == !!tile[["tile"]])
@@ -787,3 +819,6 @@
 
     return(cube)
 }
+
+
+
