@@ -46,7 +46,7 @@
         rstac::items_sign(
             items,
             sign_fn = rstac::sign_planetary_computer(
-                httr::add_headers("Ocp-Apim-Subscription-Key" = access_key)
+                headers = c("Ocp-Apim-Subscription-Key" = access_key)
             )
         )
     )
@@ -140,7 +140,7 @@
         rstac::items_sign(
             items,
             sign_fn = rstac::sign_planetary_computer(
-                httr::add_headers("Ocp-Apim-Subscription-Key" = access_key)
+                headers = c("Ocp-Apim-Subscription-Key" = access_key)
             )
         )
     )
@@ -233,6 +233,35 @@
         collection = collection
     )
 }
+#' @title Get bbox from file info for COP-DEM-GLO-30
+#' @keywords internal
+#' @noRd
+#' @param source     Data source
+#' @param file_info  File info
+#' @param ...        Additional parameters.
+#' @param collection Image collection
+#' @return vector (xmin, ymin, xmax, ymax).
+#' @export
+`.source_tile_get_bbox.mpc_cube_cop-dem-glo-30` <- function(source,
+                                                            file_info, ...,
+                                                            collection = NULL) {
+    .check_set_caller(".source_tile_get_bbox_mpc_dem_30")
+
+    # pre-condition
+    .check_num(nrow(file_info), min = 1)
+
+    # get bbox based on file_info
+    xmin <- min(file_info[["xmin"]])
+    ymin <- min(file_info[["ymin"]])
+    xmax <- max(file_info[["xmax"]])
+    ymax <- max(file_info[["ymax"]])
+
+    # post-condition
+    .check_that(xmin < xmax && ymin < ymax)
+    # create a bbox
+    bbox <- c(xmin = xmin, ymin = ymin, xmax = xmax, ymax = ymax)
+    return(bbox)
+}
 #' @keywords internal
 #' @noRd
 #' @export
@@ -283,7 +312,7 @@
     items_info <- suppressWarnings(
         rstac::items_sign(
             items_info, sign_fn = rstac::sign_planetary_computer(
-                httr::add_headers("Ocp-Apim-Subscription-Key" = access_key)
+                headers = c("Ocp-Apim-Subscription-Key" = access_key)
             )
         )
     )
@@ -365,7 +394,7 @@
         rstac::items_sign(
             items_info,
             sign_fn = rstac::sign_planetary_computer(
-                httr::add_headers("Ocp-Apim-Subscription-Key" = access_key)
+                headers = c("Ocp-Apim-Subscription-Key" = access_key)
             )
         )
     )
@@ -420,12 +449,114 @@
         rstac::items_sign(
             items,
             sign_fn = rstac::sign_planetary_computer(
-                httr::add_headers("Ocp-Apim-Subscription-Key" = access_key)
+                headers = c("Ocp-Apim-Subscription-Key" = access_key)
             )
         )
     )
     return(items)
 }
+#' @title Create an items object in MPC MODIS collection
+#' @keywords internal
+#' @noRd
+#' @description \code{.source_items_new()} this function is called to create
+#' an items object. In case of Web services, this function is responsible for
+#' making the Web requests to the server.
+#' @param source     Name of the STAC provider.
+#' @param collection Collection to be searched in the data source.
+#' @param stac_query Query that follows the STAC protocol
+#' @param ...        Other parameters to be passed for specific types.
+#' @param tiles      Selected tiles (optional)
+#' @param platform   Satellite platform (optional).
+#' @return An object referring the images of a sits cube.
+#' @export
+.source_items_new.mpc_cube <- function(source,
+                                       collection,
+                                       stac_query, ...,
+                                       tiles = NULL,
+                                       platform = NULL) {
+    .check_set_caller(".source_items_new_mpc_cube")
+    .check_that(is.null(tiles))
+    if (.has(platform)) {
+        platform <- .stac_format_platform(
+            source = source,
+            collection = collection,
+            platform = platform
+        )
+        stac_query <- rstac::ext_query(
+            q = stac_query, "platform" == platform
+        )
+    }
+    # making the request based on ROI
+    items <- rstac::post_request(q = stac_query, ...)
+    .check_stac_items(items)
+    # fetching all the metadata and updating to upper case instruments
+    items <- suppressWarnings(
+        rstac::items_fetch(items = items, progress = FALSE)
+    )
+    # assign href
+    access_key <- Sys.getenv("MPC_TOKEN")
+    if (!nzchar(access_key)) {
+        access_key <- NULL
+    }
+    # Clean old tokens cached in rstac
+    .mpc_clean_token_cache()
+    items <- suppressWarnings(
+        rstac::items_sign(
+            items,
+            sign_fn = rstac::sign_planetary_computer(
+                headers = c("Ocp-Apim-Subscription-Key" = access_key)
+            )
+        )
+    )
+    return(items)
+}
+#' @keywords internal
+#' @noRd
+#' @export
+`.source_items_new.mpc_cube_cop-dem-glo-30` <- function(source,
+                                                        collection,
+                                                        stac_query, ...,
+                                                        tiles = NULL) {
+    .check_set_caller(".source_items_new_mpc_cube_cop-dem-glo-30")
+
+    # COP-DEM-GLO-30 does not support tiles - convert to ROI
+    if (!is.null(tiles)) {
+        roi <- .s2_mgrs_to_roi(tiles)
+        stac_query[["params"]][["intersects"]] <- NULL
+        stac_query[["params"]][["bbox"]] <- c(roi[["lon_min"]],
+                                              roi[["lat_min"]],
+                                              roi[["lon_max"]],
+                                              roi[["lat_max"]]
+        )
+    }
+
+    # Fix temporal interval (All data available in the same date)
+    stac_query[["params"]][["datetime"]] <- "2021-04-21/2021-04-23"
+
+    # Search content
+    items_info <- rstac::post_request(q = stac_query, ...)
+    .check_stac_items(items_info)
+    # fetching all the metadata
+    items_info <- suppressWarnings(
+        rstac::items_fetch(items = items_info, progress = FALSE)
+    )
+
+    # assign href
+    access_key <- Sys.getenv("MPC_TOKEN")
+    if (!nzchar(access_key)) {
+        access_key <- NULL
+    }
+    # Clean old tokens cached in rstac
+    .mpc_clean_token_cache()
+    items_info <- suppressWarnings(
+        rstac::items_sign(
+            items_info, sign_fn = rstac::sign_planetary_computer(
+                headers = c("Ocp-Apim-Subscription-Key" = access_key)
+            )
+        )
+    )
+    return(items_info)
+}
 #' @keywords internal
 #' @noRd
 #' @export
@@ -462,7 +593,80 @@
                                                          collection = NULL) {
     rstac::items_reap(items, field = c("properties", "s2:mgrs_tile"))
 }
+#' @title Organizes items for MPC MOD13Q1 collections
+#' @param source     Name of the STAC provider.
+#' @param items      \code{STACItemcollection} object from rstac package.
+#' @param ...        Other parameters to be passed for specific types.
+#' @param collection Collection to be searched in the data source.
+#' @return A list of items.
+#' @keywords internal
+#' @noRd
+#' @export
+`.source_items_tile.mpc_cube_mod13q1-6.1`  <- function(source,
+                                                      items, ...,
+                                                      collection = NULL) {
+    # store tile info in items object
+    items[["features"]] <- purrr::map(items[["features"]], function(feature) {
+        h_tile <- feature[["properties"]][["modis:horizontal-tile"]]
+        v_tile <- feature[["properties"]][["modis:vertical-tile"]]
+        h_tile <- paste0("h", h_tile)
+        v_tile <- paste0("v", v_tile)
+        feature[["properties"]][["tile"]] <- paste0(h_tile, v_tile)
 
+        return(feature)
+    })
+    tile_name <- rstac::items_reap(items, field = c("properties", "tile"))
+}
+#' @title Organizes items for MPC MOD10A1 collections
+#' @param source     Name of the STAC provider.
+#' @param items      \code{STACItemcollection} object from rstac package.
+#' @param ...        Other parameters to be passed for specific types.
+#' @param collection Collection to be searched in the data source.
+#' @return A list of items.
+#' @keywords internal
+#' @noRd
+#' @export
+`.source_items_tile.mpc_cube_mod10a1-6.1`  <- function(source,
+                                                       items, ...,
+                                                       collection = NULL) {
+
+    # store tile info in items object
+    items[["features"]] <- purrr::map(items[["features"]], function(feature) {
+        h_tile <- feature[["properties"]][["modis:horizontal-tile"]]
+        v_tile <- feature[["properties"]][["modis:vertical-tile"]]
+        h_tile <- paste0("h", h_tile)
+        v_tile <- paste0("v", v_tile)
+        feature[["properties"]][["tile"]] <- paste0(h_tile, v_tile)
+
+        return(feature)
+    })
+    tile_name <- rstac::items_reap(items, field = c("properties", "tile"))
+}
+#' @title Organizes items for MPC MOD09A1 collections
+#' @param source     Name of the STAC provider.
+#' @param items      \code{STACItemcollection} object from rstac package.
+#' @param ...        Other parameters to be passed for specific types.
+#' @param collection Collection to be searched in the data source.
+#' @return A list of items.
+#' @keywords internal
+#' @noRd
+#' @export
+`.source_items_tile.mpc_cube_mod09a1-6.1`  <- function(source,
+                                                       items, ...,
+                                                       collection = NULL) {
+
+    # store tile info in items object
+    items[["features"]] <- purrr::map(items[["features"]], function(feature) {
+        h_tile <- feature[["properties"]][["modis:horizontal-tile"]]
+        v_tile <- feature[["properties"]][["modis:vertical-tile"]]
+        h_tile <- paste0("h", h_tile)
+        v_tile <- paste0("v", v_tile)
+        feature[["properties"]][["tile"]] <- paste0(h_tile, v_tile)
+
+        return(feature)
+    })
+    tile_name <- rstac::items_reap(items, field = c("properties", "tile"))
+}
 #' @title Organizes items for MPC Landsat collections
 #' @param source     Name of the STAC provider.
 #' @param items      \code{STACItemcollection} object from rstac package.
@@ -485,6 +689,20 @@
     })
     rstac::items_reap(items, field = c("properties", "tile"))
 }
+#' @title Organizes items for MPC COP-DEM-GLO-30 collections
+#' @param source     Name of the STAC provider.
+#' @param items      \code{STACItemcollection} object from rstac package.
+#' @param ...        Other parameters to be passed for specific types.
+#' @param collection Collection to be searched in the data source.
+#' @return A list of items.
+#' @keywords internal
+#' @noRd
+#' @export
+`.source_items_tile.mpc_cube_cop-dem-glo-30` <- function(source,
+                                                        items, ...,
+                                                        collection = NULL) {
+    rep("NoTilingSystem", rstac::items_length(items))
+}
 #' @title Filter S1 GRD tiles
 #' @noRd
 #' @param source  Data source
@@ -509,6 +727,70 @@
         tiles = tiles)
 
 }
+#' @title Filter COP-DEM-GLO-30 tiles
+#' @noRd
+#' @param source  Data source
+#' @param cube    Cube to be filtered
+#' @param tiles   Tiles to be selected
+#' @return Filtered cube
+#' @export
+`.source_filter_tiles.mpc_cube_cop-dem-glo-30` <- function(source,
+                                                           collection,
+                                                           cube,
+                                                           tiles) {
+    return(cube)
+}
+#' @title Get date from STAC item for MOD13Q1 collection
+#' @keywords internal
+#' @noRd
+#' @param source     Data source
+#' @param item       STAC item
+#' @param ...        Additional parameters.
+#' @param collection Image collection
+#' @return List of dates
+#' @export
+`.source_item_get_date.mpc_cube_mod13q1-6.1` <- function(source,
+                                            item, ...,
+                                            collection = NULL) {
+
+
+    datetime <- item[["properties"]][["start_datetime"]]
+    date <- lubridate::as_date(datetime)
+}
+#' @title Get date from STAC item for MOD10A1
+#' @keywords internal
+#' @noRd
+#' @param source     Data source
+#' @param item       STAC item
+#' @param ...        Additional parameters.
+#' @param collection Image collection
+#' @return List of dates
+#' @export
+`.source_item_get_date.mpc_cube_mod10a1-6.1` <- function(source,
+                                                         item, ...,
+                                                         collection = NULL) {
+
+
+    datetime <- item[["properties"]][["start_datetime"]]
+    date <- lubridate::as_date(datetime)
+}
+#' @title Get date from STAC item for MOD09A1
+#' @keywords internal
+#' @noRd
+#' @param source     Data source
+#' @param item       STAC item
+#' @param ...        Additional parameters.
+#' @param collection Image collection
+#' @return List of dates
+#' @export
+`.source_item_get_date.mpc_cube_mod09a1-6.1` <- function(source,
+                                                         item, ...,
+                                                         collection = NULL) {
+
+
+    datetime <- item[["properties"]][["start_datetime"]]
+    date <- lubridate::as_date(datetime)
+}
 #' @title Check if roi or tiles are provided
 #' @param source        Data source
 #' @param roi           Region of interest
