@@ -14,7 +14,7 @@
                                latitude,
                                crs) {
     t <- tibble::tibble(long = longitude, lat = latitude) |>
-        sf::st_as_sf(coords = c("long", "lat"), crs = 4326) |>
+        sf::st_as_sf(coords = c("long", "lat"), crs = "EPSG:4326") |>
         sf::st_transform(crs = crs) |>
         sf::st_coordinates() |>
         tibble::as_tibble()
@@ -72,7 +72,7 @@
 .intersects <- function(x, y) {
     as_crs <- sf::st_crs(x)
     y <- sf::st_transform(y, crs = as_crs)
-    apply(sf::st_intersects(x, y, sparse = FALSE), 1, any)
+    apply(suppressMessages(sf::st_intersects(x, y, sparse = FALSE)), 1, any)
 }
 #' @title Spatial within
 #' @noRd
@@ -100,7 +100,7 @@
 .within <- function(x, y) {
     as_crs <- sf::st_crs(x)
     y <- sf::st_transform(y, crs = as_crs)
-    apply(sf::st_within(x, y, sparse = FALSE), 1, any)
+    apply(suppressMessages(sf::st_within(x, y, sparse = FALSE)), 1, any)
 }
 #' @title Spatial contains
 #' @noRd
@@ -129,7 +129,7 @@
 .contains <- function(x, y) {
     as_crs <- sf::st_crs(x)
     y <- sf::st_transform(y, crs = as_crs)
-    apply(sf::st_contains(x, y, sparse = FALSE), 1, any)
+    apply(suppressMessages(sf::st_contains(x, y, sparse = FALSE)), 1, any)
 }
 #' @title Find the closest points.
 #'
