@@ -20,7 +20,7 @@
 #'     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
 #'     cube <- sits_cube(
 #'         source = "BDC",
-#'         collection = "MOD13Q1-6",
+#'         collection = "MOD13Q1-6.1",
 #'         data_dir = data_dir
 #'     )
 #'     # Get the bands from a daya cube
@@ -100,7 +100,7 @@ sits_bands.default <- function(x) {
 #' @rdname sits_bands
 #' @export
 `sits_bands<-.sits` <- function(x, value) {
-    bands <- sits_bands(x)
+    bands <- .samples_bands(x)
     .check_that(length(bands) == length(value))
     x <- .apply(x, col = "time_series", fn = function(x) {
         names(x) <- c("Index", value, "#..")
@@ -111,7 +111,7 @@ sits_bands.default <- function(x) {
 #' @rdname sits_bands
 #' @export
 `sits_bands<-.raster_cube` <- function(x, value) {
-    bands <- sits_bands(x)
+    bands <- .cube_bands(x)
     # precondition
     .check_that(length(bands) == length(value))
     x <- slider::slide_dfr(x, function(tile) {
