@@ -13,8 +13,7 @@
 #' (c) extreme gradient boosting: \code{\link[sits]{sits_xgboost}};
 #' (d) multi-layer perceptrons: \code{\link[sits]{sits_mlp}};
 #' (e) 1D CNN: \code{\link[sits]{sits_tempcnn}};
-#' (f) deep residual networks: \code{\link[sits]{sits_resnet}};
-#' (g) self-attention encoders: \code{\link[sits]{sits_lighttae}}.
+#' (f) self-attention encoders: \code{\link[sits]{sits_lighttae}}.
 #'
 #' @param  data              Data cube (tibble of class "raster_cube")
 #' @param  ml_model          R model trained by \code{\link[sits]{sits_train}}
@@ -26,17 +25,17 @@
 #'                           named lat/long values
 #'                           ("lon_min", "lat_min", "lon_max", "lat_max").
 #' @param  filter_fn         Smoothing filter to be applied - optional
-#'                           (clousure containing object of class "function").
+#'                           (closure containing object of class "function").
 #' @param  impute_fn         Imputation function to remove NA.
 #' @param  start_date        Start date for the classification
 #'                           (Date in YYYY-MM-DD format).
 #' @param  end_date          End date for the classification
-#'                           (Date im YYYY-MM-DD format).
+#'                           (Date in YYYY-MM-DD format).
 #' @param  memsize           Memory available for classification in GB
 #'                           (integer, min = 1, max = 16384).
 #' @param  multicores        Number of cores to be used for classification
 #'                           (integer, min = 1, max = 2048).
-#' @param  gpu_memory        Memory available in GPU in GB (default = 16)
+#' @param  gpu_memory        Memory available in GPU in GB (default = 4)
 #' @param  n_sam_pol         Number of time series per segment to be classified
 #'                           (integer, min = 10, max = 50).
 #' @param  output_dir        Valid directory for output file.
@@ -101,7 +100,7 @@
 #'     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
 #'     cube <- sits_cube(
 #'         source = "BDC",
-#'         collection = "MOD13Q1-6",
+#'         collection = "MOD13Q1-6.1",
 #'         data_dir = data_dir
 #'     )
 #'     # classify a data cube
@@ -170,7 +169,7 @@ sits_classify.sits <- function(data,
                                filter_fn = NULL,
                                impute_fn = impute_linear(),
                                multicores = 2L,
-                               gpu_memory = 16,
+                               gpu_memory = 4,
                                progress = TRUE) {
     # set caller for error messages
     .check_set_caller("sits_classify_sits")
@@ -180,9 +179,11 @@ sits_classify.sits <- function(data,
     .check_int_parameter(multicores, min = 1, max = 2048)
     .check_progress(progress)
     # Update multicores: xgb model does its own parallelization
-    if (inherits(ml_model, "xgb_model")) {
+    if (inherits(ml_model, "xgb_model"))
         multicores <- 1
-    }
+    # for MPS, set gpu memory to 1 GB
+    if (inherits(ml_model, "torch_model") && .torch_has_mps())
+        gpu_memory <- 1
     # Do classification
     classified_ts <- .classify_ts(
         samples = data,
@@ -207,7 +208,7 @@ sits_classify.raster_cube <- function(data,
                                       end_date = NULL,
                                       memsize = 8L,
                                       multicores = 2L,
-                                      gpu_memory = 16,
+                                      gpu_memory = 4,
                                       output_dir,
                                       version = "v1",
                                       verbose = FALSE,
@@ -227,17 +228,24 @@ sits_classify.raster_cube <- function(data,
     # Get default proc bloat
     proc_bloat <- .conf("processing_bloat_cpu")
     # If we using the GPU, gpu_memory parameter needs to be specified
-    if (.is_torch_model(ml_model)) {
+    if (.torch_cuda_enabled(ml_model)) {
         .check_int_parameter(gpu_memory, min = 1, max = 16384,
                              msg = .conf("messages", ".check_gpu_memory")
         )
         # Calculate available memory from GPU
         memsize <- floor(gpu_memory - .torch_mem_info())
-        .check_int_parameter(memsize, min = 2,
+        .check_int_parameter(memsize, min = 1,
                         msg = .conf("messages", ".check_gpu_memory_size")
         )
         proc_bloat <- .conf("processing_bloat_gpu")
     }
+    # avoid memory race in Apple MPS
+    if(.torch_mps_enabled(ml_model)){
+        memsize <- 1
+        gpu_memory <- 1
+    }
+    # save memsize for latter use
+    sits_env[["gpu_memory"]] <- gpu_memory
     # Spatial filter
     if (.has(roi)) {
         roi <- .roi_as_sf(roi)
@@ -253,22 +261,41 @@ sits_classify.raster_cube <- function(data,
         .check_filter_fn(filter_fn)
     # Retrieve the samples from the model
     samples <- .ml_samples(ml_model)
+    # By default, base bands is null.
+    base_bands <- NULL
+    if (.cube_is_base(data)) {
+        # Get base bands
+        base_bands <- intersect(
+            .ml_bands(ml_model), .cube_bands(.cube_base_info(data))
+        )
+    }
+    # get non-base bands
+    bands <- setdiff(.ml_bands(ml_model), base_bands)
     # Do the samples and tile match their timeline length?
     .check_samples_tile_match_timeline(samples = samples, tile = data)
     # Do the samples and tile match their bands?
     .check_samples_tile_match_bands(samples = samples, tile = data)
-    # Check memory and multicores
     # Get block size
     block <- .raster_file_blocksize(.raster_open_rast(.tile_path(data)))
     # Check minimum memory needed to process one block
     job_memsize <- .jobs_memsize(
         job_size = .block_size(block = block, overlap = 0),
-        npaths = length(.tile_paths(data)) + length(.ml_labels(ml_model)),
+        npaths = (
+            length(.tile_paths(data, bands)) +
+            length(.ml_labels(ml_model)) +
+            ifelse(
+                test = .cube_is_base(data),
+                yes = length(.tile_paths(.cube_base_info(data), base_bands)),
+                no = 0
+            )
+        ),
         nbytes = 8,
         proc_bloat = proc_bloat
     )
     # Update multicores parameter
-    if ("xgb_model" %in% .ml_class(ml_model) || .is_torch_model(ml_model))
+    if ("xgb_model" %in% .ml_class(ml_model))
+        multicores <- 1
+    else if (.torch_mps_enabled(ml_model) || .torch_cuda_enabled(ml_model))
         multicores <- 1
     else
         # Update multicores parameter
@@ -302,7 +329,9 @@ sits_classify.raster_cube <- function(data,
         # Classify the data
         probs_tile <- .classify_tile(
             tile = tile,
-            band = "probs",
+            out_band = "probs",
+            bands = bands,
+            base_bands = base_bands,
             ml_model = ml_model,
             block = block,
             roi = roi,
@@ -352,7 +381,7 @@ sits_classify.segs_cube <- function(data,
                                     end_date = NULL,
                                     memsize = 8L,
                                     multicores = 2L,
-                                    gpu_memory = 16,
+                                    gpu_memory = 4,
                                     output_dir,
                                     version = "v1",
                                     n_sam_pol = NULL,
@@ -372,8 +401,8 @@ sits_classify.segs_cube <- function(data,
     version <- .check_version(version)
     .check_progress(progress)
     proc_bloat <- .conf("processing_bloat_seg_class")
-    # If we using the GPU, gpu_memory parameter needs to be specified
-    if (.is_torch_model(ml_model)) {
+    # If we using CUDA, gpu_memory parameter needs to be specified
+    if (.torch_cuda_enabled(ml_model)) {
         .check_int_parameter(gpu_memory, min = 1, max = 16384,
                              msg = .conf("messages", ".check_gpu_memory")
         )
@@ -384,6 +413,11 @@ sits_classify.segs_cube <- function(data,
         )
         proc_bloat <- .conf("processing_bloat_gpu")
     }
+    # avoid memory race in Apple MPS
+    if(.torch_mps_enabled(ml_model)){
+        memsize <- 1
+        gpu_memory <- 1
+    }
     # Spatial filter
     if (.has(roi)) {
         roi <- .roi_as_sf(roi)
@@ -397,6 +431,16 @@ sits_classify.segs_cube <- function(data,
     }
     if (.has(filter_fn))
         .check_filter_fn(filter_fn)
+    # By default, base bands is null.
+    base_bands <- NULL
+    if (.cube_is_base(data)) {
+        # Get base bands
+        base_bands <- intersect(
+            .ml_bands(ml_model), .cube_bands(.cube_base_info(data))
+        )
+    }
+    # get non-base bands
+    bands <- setdiff(.ml_bands(ml_model), base_bands)
     # Check memory and multicores
     # Get block size
     block <- .raster_file_blocksize(.raster_open_rast(.tile_path(data)))
@@ -439,6 +483,8 @@ sits_classify.segs_cube <- function(data,
         # Classify all the segments for each tile
         class_vector <- .classify_vector_tile(
             tile = tile,
+            bands = bands,
+            base_bands = base_bands,
             ml_model = ml_model,
             block = block,
             roi = roi,
