@@ -54,8 +54,8 @@ sits_merge.sits <- function(data1, data2, ..., suffix = c(".1", ".2")) {
     # verify if data1 and data2 have the same number of rows
     .check_that(nrow(data1) == nrow(data2))
     # are the names of the bands different?
-    bands1 <- sits_bands(data1)
-    bands2 <- sits_bands(data2)
+    bands1 <- .samples_bands(data1)
+    bands2 <- .samples_bands(data2)
     coincidences1 <- bands1 %in% bands2
     coincidences2 <- bands2 %in% bands1
     if (any(coincidences1) || any(coincidences2)) {
@@ -105,6 +105,9 @@ sits_merge.sar_cube <- function(data1, data2, ...) {
         dplyr::filter(data2, .data[["tile"]] %in% common_tiles),
         .data[["tile"]]
     )
+    if (length(.cube_timeline(data2)[[1]]) == 1){
+        return(.merge_single_timeline(data1, data2))
+    }
     if (inherits(data2, "sar_cube")) {
         return(.merge_equal_cube(data1, data2))
     } else {
@@ -131,11 +134,13 @@ sits_merge.raster_cube <- function(data1, data2, ...) {
         dplyr::filter(data2, .data[["tile"]] %in% common_tiles),
         .data[["tile"]]
     )
-
-    if (inherits(data2, "raster_cube")) {
-        return(.merge_equal_cube(data1, data2))
-    } else {
+    if (length(.cube_timeline(data2)[[1]]) == 1){
+        return(.merge_single_timeline(data1, data2))
+    }
+    if (inherits(data2, "sar_cube")) {
         return(.merge_distinct_cube(data1, data2))
+    } else {
+        return(.merge_equal_cube(data1, data2))
     }
 }
 
@@ -152,14 +157,14 @@ sits_merge.raster_cube <- function(data1, data2, ...) {
 
 .merge_distinct_cube <- function(data1, data2) {
     # Get cubes timeline
-    d1_tl <- unique(as.Date(unlist(.cube_timeline(data1))))
-    d2_tl <- unique(as.Date(unlist(.cube_timeline(data2))))
+    d1_tl <- unique(as.Date(.cube_timeline(data1)[[1]]))
+    d2_tl <- unique(as.Date(.cube_timeline(data2)[[1]]))
 
     # get intervals
-    d1_period <- as.numeric(
+    d1_period <- as.integer(
         lubridate::as.period(lubridate::int_diff(d1_tl)), "days"
     )
-    d2_period <- as.numeric(
+    d2_period <- as.integer(
         lubridate::as.period(lubridate::int_diff(d2_tl)), "days"
     )
     # pre-condition - are periods regular?
@@ -198,6 +203,28 @@ sits_merge.raster_cube <- function(data1, data2, ...) {
     return(data1)
 }
 
+.merge_single_timeline <- function(data1, data2) {
+    tiles <- .cube_tiles(data1)
+    # update the timeline of the cube with single time step (`data2`)
+    data2 <- .map_dfr(tiles, function(tile_name) {
+        tile_data1 <- .cube_filter_tiles(data1, tile_name)
+        tile_data2 <- .cube_filter_tiles(data2, tile_name)
+        # Get data1 timeline.
+        d1_tl <- unique(as.Date(.cube_timeline(tile_data1)[[1]]))
+        # Create new `file_info` using dates from `data1` timeline.
+        fi_new <- purrr::map(.tile_timeline(tile_data1), function(date_row) {
+            fi <- .fi(tile_data2)
+            fi[["date"]] <- as.Date(date_row)
+            fi
+        })
+        # Assign the new `file_into` into `data2`
+        tile_data2[["file_info"]] <- list(dplyr::bind_rows(fi_new))
+        tile_data2
+    })
+    # Merge cubes and return
+    .cube_merge(data1, data2)
+}
+
 #' @rdname sits_merge
 #' @export
 sits_merge.default <- function(data1, data2, ...) {
