@@ -58,14 +58,15 @@
 #' @examples
 #' if (sits_run_examples()) {
 #'     # create an MLP model
-#'     torch_model <- sits_train(samples_modis_ndvi, sits_mlp())
+#'     torch_model <- sits_train(samples_modis_ndvi,
+#'            sits_mlp(epochs = 20, verbose = TRUE))
 #'     # plot the model
 #'     plot(torch_model)
 #'     # create a data cube from local files
 #'     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
 #'     cube <- sits_cube(
 #'         source = "BDC",
-#'         collection = "MOD13Q1-6",
+#'         collection = "MOD13Q1-6.1",
 #'         data_dir = data_dir
 #'     )
 #'     # classify a data cube
@@ -92,7 +93,7 @@ sits_mlp <- function(samples = NULL,
                      samples_validation = NULL,
                      layers = c(512, 512, 512),
                      dropout_rates = c(0.20, 0.30, 0.40),
-                     optimizer = torchopt::optim_adamw,
+                     optimizer = torch::optim_adamw,
                      opt_hparams = list(
                          lr = 0.001,
                          eps = 1e-08,
@@ -108,6 +109,9 @@ sits_mlp <- function(samples = NULL,
     .check_set_caller("sits_mlp")
     # Function that trains a torch model based on samples
     train_fun <- function(samples) {
+        # does not support working with DEM or other base data
+        if (inherits(samples, "sits_base"))
+            stop(.conf("messages", "sits_train_base_data"), call. = FALSE)
         # Avoid add a global variable for 'self'
         self <- NULL
         # Verifies if 'torch' and 'luz' packages is installed
@@ -154,7 +158,7 @@ sits_mlp <- function(samples = NULL,
         # Samples bands
         bands <- .samples_bands(samples)
         # Samples timeline
-        timeline <- sits_timeline(samples)
+        timeline <- .samples_timeline(samples)
         # Create numeric labels vector
         code_labels <- seq_along(labels)
         names(code_labels) <- labels
@@ -201,7 +205,6 @@ sits_mlp <- function(samples = NULL,
         test_y <- unname(code_labels[.pred_references(test_samples)])
         # Set torch seed
         torch::torch_manual_seed(sample.int(10^5, 1))
-
         # Define the MLP architecture
         mlp_model <- torch::nn_module(
             initialize = function(num_pred, layers, dropout_rates, y_dim) {
@@ -227,8 +230,8 @@ sits_mlp <- function(samples = NULL,
                 # output layer
                 tensors[[length(tensors) + 1]] <-
                     torch::nn_linear(layers[length(layers)], y_dim)
-                # add softmax tensor
-                tensors[[length(tensors) + 1]] <- torch::nn_softmax(dim = 2)
+               # softmax is done externally
+               # tensors[[length(tensors) + 1]] <- torch::nn_softmax(dim = 2)
                 # create a sequential module that calls the layers in the same
                 # order.
                 self$model <- torch::nn_sequential(!!!tensors)
@@ -237,6 +240,8 @@ sits_mlp <- function(samples = NULL,
                 self$model(x)
             }
         )
+        # Train with CPU or GPU?
+        cpu_train <- .torch_cpu_train()
         # Train the model using luz
         torch_model <-
             luz::setup(
@@ -262,6 +267,8 @@ sits_mlp <- function(samples = NULL,
                     patience = patience,
                     min_delta = min_delta
                 )),
+                dataloader_options = list(batch_size = batch_size),
+                accelerator = luz::accelerator(cpu = cpu_train),
                 verbose = verbose
             )
         # Serialize model
@@ -277,36 +284,33 @@ sits_mlp <- function(samples = NULL,
             # Unserialize model
             torch_model[["model"]] <- .torch_unserialize_model(serialized_model)
             # Used to check values (below)
-            n_input_pixels <- nrow(values)
+            input_pixels <- nrow(values)
             # Performs data normalization
             values <- .pred_normalize(pred = values, stats = ml_stats)
             # Transform input into matrix
             values <- as.matrix(values)
-            # if CUDA is available, transform to torch data set
-            # Load into GPU
-            if (torch::cuda_is_available()) {
+            # Get GPU memory
+            gpu_memory <- sits_env[["gpu_memory"]]
+            # if CUDA is available and gpu memory is defined, transform values
+            # to torch dataloader
+            if (.torch_has_cuda() && .has(gpu_memory)) {
+                # set the batch size according to the GPU memory
+                b_size <- 2^gpu_memory
+                # transfor the input array to a dataset
                 values <- .as_dataset(values)
-                # We need to transform in a dataloader to use the batch size
-                values <- torch::dataloader(
-                    values, batch_size = 2^15
-                )
-                # Do GPU classification
+                # To the data set to a torcj  transform in a dataloader to use the batch size
+                values <- torch::dataloader(values, batch_size = b_size)
+                # Do GPU classification with dataloader
                 values <- .try(
                     stats::predict(object = torch_model, values),
                     .msg_error = .conf("messages", ".check_gpu_memory_size")
                 )
             } else {
-                # Do CPU classification
+                # Do  classification without dataloader
                 values <- stats::predict(object = torch_model, values)
             }
-            # Convert to tensor cpu to support GPU processing
-            values <- torch::as_array(
-                x = torch::torch_tensor(values, device = "cpu")
-            )
-            # Are the results consistent with the data input?
-            .check_processed_values(
-                values = values, n_input_pixels = n_input_pixels
-            )
+            # Convert from tensor to array
+            values <- torch::as_array(values)
             # Update the columns names to labels
             colnames(values) <- labels
             return(values)
