@@ -11,7 +11,7 @@
 #' @param dates      Character vector with sparse dates to select.
 #'
 #' @description      Filter only the selected bands and dates
-#'                   from a set of time series or froam a data cube.
+#'                   from a set of time series or from a data cube.
 #'
 #' @return           Tibble with time series or data cube.
 #'
@@ -37,7 +37,7 @@ sits_select <- function(data,
     # set caller to show in errors
     .check_set_caller("sits_select")
     # check data
-    .check_valid(data)
+    .check_na_null_parameter(data)
     # get the meta-type (sits or cube)
     UseMethod("sits_select", data)
 }
@@ -51,22 +51,22 @@ sits_select.sits <- function(data,
     # Pre-condition
     .check_samples_ts(data)
     # Filter bands
-    if (!purrr::is_null(bands) && !any(is.na(bands))) {
+    if (.has(bands) && !anyNA(bands)) {
         # sits tibble only works with non-processed cubes
         # all bands are uppercase
         bands <- toupper(bands)
         # check bands parameter
-        .check_chr(bands,
+        .check_chr_parameter(bands,
                    allow_empty = FALSE,
                    allow_duplicate = FALSE,
                    len_min = 1,
-                   len_max = length(sits_bands(data)),
-                   msg = "Invalid bands parameter")
+                   len_max = length(.samples_bands(data))
+        )
 
         # select bands from the time series
         data <- .samples_select_bands(data, bands = bands)
     }
-    if (!purrr::is_null(start_date) && !purrr::is_null(end_date)) {
+    if (.has(start_date) && .has(end_date)) {
         # Filter dates
         start_date <- .timeline_format(start_date)
         end_date   <- .timeline_format(end_date)
@@ -87,42 +87,15 @@ sits_select.raster_cube <- function(data,
                                     end_date = NULL, ...,
                                     dates = NULL,
                                     tiles = NULL) {
-    # Pre-condition
-    .check_cube_files(data)
-    # Filter bands
-    if (!purrr::is_null(bands) && !any(is.na(bands))) {
-        bands <- .band_set_case(bands)
-        bands <- .default(bands, .band_samples(sits_bands(data)))
-        # check bands parameter
-        .check_chr(bands,
-                   allow_empty = FALSE,
-                   allow_duplicate = FALSE,
-                   len_min = 1,
-                   len_max = length(sits_bands(data)),
-                   msg = "Invalid bands parameter")
-
-        # filter the selected bands
-        data <- .cube_filter_bands(cube = data, bands = bands)
-    }
-    # Filter by dates
-    if (!purrr::is_null(dates)) {
-        dates <- .timeline_format(dates)
-        data <- .cube_filter_dates(cube = data, dates = dates)
-    }
-    # Filter by period
-    if (!purrr::is_null(start_date) && !purrr::is_null(end_date)
-        && !is.na(start_date) && !is.na(end_date)) {
-        start_date <- .timeline_format(start_date)
-        end_date   <- .timeline_format(end_date)
-        data <- .cube_filter_interval(
-            cube = data, start_date = start_date, end_date = end_date
-        )
-    }
-    # Filter tiles
-    if (!purrr::is_null(tiles) && !any(is.na(tiles))) {
-        .check_chr_type(tiles)
-        data <- .cube_filter_tiles(cube = data, tiles = tiles)
-    }
+    # Call internal function
+    data <- .select_raster_cube(
+        data = data,
+        bands = bands,
+        start_date = start_date,
+        end_date = end_date,
+        dates = dates,
+        tiles = tiles
+    )
     return(data)
 }
 #' @rdname sits_select
@@ -134,19 +107,14 @@ sits_select.patterns <- function(data, bands = NULL,
 }
 #' @rdname sits_select
 #' @export
-sits_select.tbl_df <- function(data,...) {
+sits_select.default <- function(data, ...) {
     data <- tibble::as_tibble(data)
-    if (all(.conf("sits_cube_cols") %in% colnames(data))) {
+    if (all(.conf("sits_cube_cols") %in% colnames(data)))
         data <- .cube_find_class(data)
-    } else if (all(.conf("sits_tibble_cols") %in% colnames(data))) {
+    else if (all(.conf("sits_tibble_cols") %in% colnames(data)))
         class(data) <- c("sits", class(data))
-    } else
-        stop("Input should be a sits tibble or a data cube")
+    else
+        stop(.conf("messages", "sits_select"))
     data <- sits_select(data, ...)
     return(data)
 }
-#' @rdname sits_select
-#' @export
-sits_select.default <- function(data, ...){
-    stop("input should an object of class cube or class sits")
-}
