@@ -59,14 +59,15 @@
 #' @examples
 #' if (sits_run_examples()) {
 #'     # create a TempCNN model
-#'     torch_model <- sits_train(samples_modis_ndvi, sits_tempcnn())
+#'     torch_model <- sits_train(samples_modis_ndvi,
+#'                sits_tempcnn(epochs = 20, verbose = TRUE))
 #'     # plot the model
 #'     plot(torch_model)
 #'     # create a data cube from local files
 #'     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
 #'     cube <- sits_cube(
 #'         source = "BDC",
-#'         collection = "MOD13Q1-6",
+#'         collection = "MOD13Q1-6.1",
 #'         data_dir = data_dir
 #'     )
 #'     # classify a data cube
@@ -90,7 +91,7 @@
 #' @export
 sits_tempcnn <- function(samples = NULL,
                          samples_validation = NULL,
-                         cnn_layers = c(256, 256, 256),
+                         cnn_layers = c(64, 64, 64),
                          cnn_kernels = c(5, 5, 5),
                          cnn_dropout_rates = c(0.20, 0.20, 0.20),
                          dense_layer_nodes = 256,
@@ -100,7 +101,7 @@ sits_tempcnn <- function(samples = NULL,
                          validation_split = 0.2,
                          optimizer = torch::optim_adamw,
                          opt_hparams = list(
-                             lr = 0.005,
+                             lr = 5.0e-04,
                              eps = 1.0e-08,
                              weight_decay = 1.0e-06
                          ),
@@ -113,6 +114,9 @@ sits_tempcnn <- function(samples = NULL,
     .check_set_caller("sits_tempcnn")
     # Function that trains a torch model based on samples
     train_fun <- function(samples) {
+        # does not support working with DEM or other base data
+        if (inherits(samples, "sits_base"))
+            stop(.conf("messages", "sits_train_base_data"), call. = FALSE)
         # Avoid add a global variable for 'self'
         self <- NULL
         # Verifies if 'torch' and 'luz' packages is installed
@@ -164,7 +168,7 @@ sits_tempcnn <- function(samples = NULL,
         # Samples bands
         bands <- .samples_bands(samples)
         # Samples timeline
-        timeline <- sits_timeline(samples)
+        timeline <- .samples_timeline(samples)
         # Create numeric labels vector
         code_labels <- seq_along(labels)
         names(code_labels) <- labels
@@ -267,10 +271,10 @@ sits_tempcnn <- function(samples = NULL,
                     output_dim   = dense_layer_nodes,
                     dropout_rate = dense_layer_dropout_rate
                 )
-                # classification using softmax
-                self$softmax <- torch::nn_sequential(
-                    torch::nn_linear(dense_layer_nodes, n_labels),
-                    torch::nn_softmax(dim = -1)
+                # reduce to linear tensor with n_labels
+                # softmax is done externally
+                self$nn_linear <- torch::nn_sequential(
+                    torch::nn_linear(dense_layer_nodes, n_labels)
                 )
             },
             forward = function(x) {
@@ -282,9 +286,11 @@ sits_tempcnn <- function(samples = NULL,
                     self$conv_bn_relu3() |>
                     self$flatten() |>
                     self$dense() |>
-                    self$softmax()
+                    self$nn_linear()
             }
         )
+        # train with CPU or GPU?
+        cpu_train <- .torch_cpu_train()
         # Train the model using luz
         torch_model <-
             luz::setup(
@@ -323,6 +329,7 @@ sits_tempcnn <- function(samples = NULL,
                         gamma = lr_decay_rate
                     )
                 ),
+                accelerator = luz::accelerator(cpu = cpu_train),
                 dataloader_options = list(batch_size = batch_size),
                 verbose = verbose
             )
@@ -339,7 +346,7 @@ sits_tempcnn <- function(samples = NULL,
             # Unserialize model
             torch_model[["model"]] <- .torch_unserialize_model(serialized_model)
             # Used to check values (below)
-            n_input_pixels <- nrow(values)
+            input_pixels <- nrow(values)
             # Transform input into a 3D tensor
             # Reshape the 2D matrix into a 3D array
             n_samples <- nrow(values)
@@ -351,31 +358,28 @@ sits_tempcnn <- function(samples = NULL,
             values <- array(
                 data = as.matrix(values), dim = c(n_samples, n_times, n_bands)
             )
-            # if CUDA is available, transform to torch data set
-            # Load into GPU
-            if (torch::cuda_is_available()) {
+            # Get GPU memory
+            gpu_memory <- sits_env[["gpu_memory"]]
+            # if CUDA is available and gpu memory is defined, transform values
+            # to torch dataloader
+            if (.torch_has_cuda() && .has(gpu_memory)) {
+                # set the batch size according to the GPU memory
+                b_size <- 2^gpu_memory
+                # transfor the input array to a dataset
                 values <- .as_dataset(values)
-                # We need to transform in a dataloader to use the batch size
-                values <- torch::dataloader(
-                    values, batch_size = 2^15
-                )
-                # Do GPU classification
+                # To the data set to a torch transform in a dataloader to use the batch size
+                values <- torch::dataloader(values, batch_size = b_size)
+                # Do GPU classification with dataloader
                 values <- .try(
                     stats::predict(object = torch_model, values),
                     .msg_error = .conf("messages", ".check_gpu_memory_size")
                 )
             } else {
-                # Do CPU classification
+                # Do  classification without dataloader
                 values <- stats::predict(object = torch_model, values)
             }
-            # Convert to tensor cpu to support GPU processing
-            values <- torch::as_array(
-                x = torch::torch_tensor(values, device = "cpu")
-            )
-            # Are the results consistent with the data input?
-            .check_processed_values(
-                values = values, n_input_pixels = n_input_pixels
-            )
+            # Convert from tensor to array
+            values <- torch::as_array(values)
             # Update the columns names to labels
             colnames(values) <- labels
             return(values)
