@@ -29,9 +29,9 @@
 #'   \code{ml_method}. User can use \code{uniform}, \code{choice},
 #'   \code{randint}, \code{normal}, \code{lognormal}, \code{loguniform},
 #'   and \code{beta} distribution functions to randomize parameters.
-#' @param trials Number of random trials to perform the random search.
-#' @param progress           Show progress bar?
-#' @param multicores         Number of cores to process in parallel
+#' @param trials        Number of random trials to perform the random search.
+#' @param progress      Show progress bar?
+#' @param multicores    Number of cores to process in parallel.
 #'
 #' @return
 #' A tibble containing all parameters used to train on each trial
@@ -67,7 +67,7 @@ sits_tuning <- function(samples,
                         validation_split = 0.2,
                         ml_method = sits_tempcnn(),
                         params = sits_tuning_hparams(
-                            optimizer = torchopt::optim_adamw,
+                            optimizer = torch::optim_adamw,
                             opt_hparams = list(
                                 lr = loguniform(10^-2, 10^-4)
                             )
@@ -80,41 +80,34 @@ sits_tuning <- function(samples,
     # pre-conditions
     # check samples
     .check_samples_train(samples)
-    # check samples_validation parameter if it is passed
-    if (!purrr::is_null(samples_validation)) {
+    if (.has(samples_validation)) {
+        # check samples_validation parameter if it exists
         .check_samples_train(samples_validation)
-    }
-    # check validation_split parameter if samples_validation is not passed
-    if (purrr::is_null(samples_validation)) {
+    } else {
+        # check validation_split parameter if samples_validation is not passed
         .check_num_parameter(validation_split, exclusive_min = 0, max = 0.5)
     }
     # check 'ml_functions' parameter
     ml_function <- substitute(ml_method, env = environment())
-    if (is.call(ml_function)) ml_function <- ml_function[[1]]
+    if (is.call(ml_function))
+        ml_function <- ml_function[[1]]
     ml_function <- eval(ml_function, envir = asNamespace("sits"))
     # check 'params' parameter
-    .check_lst(
-        x = params,
-        min_len = 1,
-        msg = "invalid 'params' parameter"
-    )
-    .check_that(
-        x = !"samples" %in% names(params),
-        local_msg = "cannot pass 'samples' via hyper-parameters",
-        msg = "invalid 'params' parameter"
+    .check_lst_parameter(params, len_min = 1)
+    .check_that(!"samples" %in% names(params),
+        msg = .conf("messages", "sits_tuning_samples")
     )
     params_default <- formals(ml_function)
     .check_chr_within(
         x = names(params),
-        within = names(params_default),
-        msg = "invalid 'params' parameter"
+        within = names(params_default)
     )
     # update formals with provided parameters in params
     params <- utils::modifyList(params_default, params)
     # check trials
     .check_int_parameter(trials)
     # check 'multicores' parameter
-    .check_multicores(multicores, min = 1, max = 2048)
+    .check_int_parameter(multicores, min = 1, max = 2048)
     # generate random params
     params_lst <- purrr::map(
         as.list(seq_len(trials)),
@@ -151,7 +144,7 @@ sits_tuning <- function(samples,
     # prepare result
     result <- dplyr::bind_rows(result_lst)
     # convert parameters to a tibble
-    params_tb <- purrr::map_dfr(params_lst, .tuning_params_as_tibble)
+    params_tb <- .map_dfr(params_lst, .tuning_params_as_tibble)
     # bind results and parameters
     tuning_tb <- dplyr::bind_cols(result, params_tb)
     # order by accuracy
@@ -204,14 +197,15 @@ sits_tuning <- function(samples,
 #'         ml_method = sits_tempcnn(),
 #'         params = sits_tuning_hparams(
 #'             optimizer = choice(
-#'                 torchopt::optim_adamw,
-#'                 torchopt::optim_yogi
+#'                 torch::optim_adamw,
+#'                 torch::optim_adagrad
 #'             ),
 #'             opt_hparams = list(
-#'                 lr = beta(0.3, 5)
+#'                  lr = loguniform(10^-2, 10^-4),
+#'                  weight_decay = loguniform(10^-2, 10^-8)
 #'             )
 #'         ),
-#'         trials = 4,
+#'         trials = 20,
 #'         multicores = 2,
 #'         progress = FALSE
 #'     )
