@@ -3,12 +3,9 @@ devAskNewPage(ask = FALSE)
 # load the sits library
 library(sits)
 if (!requireNamespace("sitsdata", quietly = TRUE)) {
-    stop(
-        paste0(
-            "Please install package sitsdata\n",
-            "Please call devtools::install_github('e-sensing/sitsdata')"
-        ),
-        call. = FALSE
+    stop("Please install package sitsdata\n",
+         "Please call devtools::install_github('e-sensing/sitsdata')",
+         call. = FALSE
     )
 }
 
@@ -22,32 +19,24 @@ results <- list()
 # Deep Learning - MLP
 
 print("== Accuracy Assessment = DL =======================")
-acc_ltae <- sits_kfold_validate(samples_matogrosso_mod13q1,
+acc_ltae <- sits_kfold_validate(
+    samples_matogrosso_mod13q1,
     folds = 5,
     ml_method = sits_lighttae()
 )
-acc_ltae$name <- "LightTAE"
+acc_ltae[["name"]] <- "LightTAE"
 
 results[[length(results) + 1]] <- acc_ltae
 
 # Deep Learning - TempCNN
 print("== Accuracy Assessment = TempCNN =======================")
-acc_tc <- sits_kfold_validate(samples_matogrosso_mod13q1,
+acc_tc <- sits_kfold_validate(
+    samples_matogrosso_mod13q1,
     folds = 5,
     ml_method = sits_tempcnn()
 )
-acc_tc$name <- "TempCNN"
+acc_tc[["name"]] <- "TempCNN"
 
 results[[length(results) + 1]] <- acc_tc
 
-# Deep Learning - ResNet
-print("== Accuracy Assessment = ResNet =======================")
-acc_rn <- sits_kfold_validate(samples_matogrosso_mod13q1,
-    folds = 5,
-    ml_method = sits_resnet()
-)
-acc_rn$name <- "ResNet"
-
-results[[length(results) + 1]] <- acc_rn
-
-sits_to_xlsx(results, file = paste0(tempdir(), "/accuracy_mato_grosso_dl.xlsx"))
+sits_to_xlsx(results, file = file.path(tempdir(), "/accuracy_mato_grosso_dl.xlsx"))
