@@ -3,7 +3,7 @@ test_that("Suggested samples have low confidence, high entropy", {
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
     cube <- sits_cube(
         source = "BDC",
-        collection = "MOD13Q1-6",
+        collection = "MOD13Q1-6.1",
         data_dir = data_dir,
         progress = FALSE
     )
@@ -34,7 +34,9 @@ test_that("Suggested samples have low confidence, high entropy", {
         uncert_cube,
         min_uncert = 0.3,
         n = 100,
-        sampling_window = 10
+        sampling_window = 10,
+        multicores = 2,
+        memsize = 2
     ))
 
     expect_true(nrow(samples_df) <= 100)
@@ -56,7 +58,7 @@ test_that("Increased samples have high confidence, low entropy", {
     out_dir <- tempdir()
     cube <- sits_cube(
         source = "BDC",
-        collection = "MOD13Q1-6",
+        collection = "MOD13Q1-6.1",
         data_dir = data_dir,
         progress = FALSE
     )
@@ -80,7 +82,9 @@ test_that("Increased samples have high confidence, low entropy", {
             probs_cube = probs_cube,
             n = 20,
             min_margin = 0.5,
-            sampling_window = 10
+            sampling_window = 10,
+            multicores = 2,
+            memsize = 2
         )
     )
     expect_warning(
@@ -88,7 +92,9 @@ test_that("Increased samples have high confidence, low entropy", {
             probs_cube = probs_cube,
             n = 60,
             min_margin = 0.5,
-            sampling_window = 10
+            sampling_window = 10,
+            multicores = 2,
+            memsize = 2
         )
     )
     labels <- sits_labels(probs_cube)
