@@ -2,7 +2,7 @@ test_that("Reading a LAT/LONG from RASTER", {
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
     raster_cube <- sits_cube(
         source = "BDC",
-        collection = "MOD13Q1-6",
+        collection = "MOD13Q1-6.1",
         data_dir = data_dir,
         progress = FALSE
     )
@@ -14,6 +14,11 @@ test_that("Reading a LAT/LONG from RASTER", {
     expect_equal(names(point_ndvi)[1], "longitude")
     expect_true(ncol(.tibble_time_series(point_ndvi)) == 2)
     expect_true(length(sits_timeline(point_ndvi)) == 12)
+    expect_true(
+        all(
+            c("sits", "tbl_df", "tbl", "data.frame") %in% class(point_ndvi)
+        )
+    )
 
     samples2 <- tibble::tibble(longitude = -55.66738, latitude = 11.76990)
     expect_warning(
@@ -25,7 +30,7 @@ test_that("Reading a CSV file from RASTER", {
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
     raster_cube <- sits_cube(
         source = "BDC",
-        collection = "MOD13Q1-6",
+        collection = "MOD13Q1-6.1",
         data_dir = data_dir,
         progress = TRUE
     )
@@ -49,6 +54,11 @@ test_that("Reading a CSV file from RASTER", {
     expect_equal(length(names(points_poly)), 7)
     expect_true(ncol(.tibble_time_series(points_poly)) == 2)
     expect_true(length(sits_timeline(points_poly)) == 12)
+    expect_true(
+        all(
+            c("sits", "tbl_df", "tbl", "data.frame") %in% class(points_poly)
+        )
+    )
 
     Sys.setenv("SITS_SAMPLES_CACHE_DIR" = tempdir())
 
@@ -63,6 +73,12 @@ test_that("Reading a CSV file from RASTER", {
     expect_equal(length(names(points_df)), 7)
     expect_true(ncol(.tibble_time_series(points_df)) == 2)
     expect_true(length(sits_timeline(points_df)) == 12)
+    expect_true(
+        all(
+            c("sits", "tbl_df", "tbl", "data.frame") %in% class(points_df)
+        )
+    )
+
     Sys.unsetenv("SITS_SAMPLES_CACHE_DIR")
 })
 
@@ -79,18 +95,19 @@ test_that("Retrieving points from BDC using POLYGON shapefiles", {
         {
             sits_cube(
                 source = "BDC",
-                collection = "MOD13Q1-6",
+                collection = "MOD13Q1-6.1",
                 bands = c("NDVI", "EVI"),
                 roi = sf_mt,
-                start_date = "2018-09-01",
-                end_date = "2019-08-29",
+                start_date = "2019-10-01",
+                end_date = "2019-12-30",
+                multicores = 1,
                 progress = FALSE
             )
         },
         .default = NULL
     )
     testthat::skip_if(purrr::is_null(modis_cube),
-        message = "BDC is not accessible"
+        message = "MPC is not accessible"
     )
     # get the timeline
     cube_timeline <- sits_timeline(modis_cube)
@@ -112,6 +129,11 @@ test_that("Retrieving points from BDC using POLYGON shapefiles", {
         object = unique(points_shp[["end_date"]]),
         expected = as.Date(cube_timeline[length(cube_timeline)])
     )
+    expect_true(
+        all(
+            c("sits", "tbl_df", "tbl", "data.frame") %in% class(points_shp)
+        )
+    )
 
     # test bounding box
     polygons_bbox <- .bbox(sf_mt)
@@ -195,7 +217,7 @@ test_that("Retrieving points from BDC using POINT shapefiles", {
         {
             sits_cube(
                 source = "BDC",
-                collection = "MOD13Q1-6",
+                collection = "MOD13Q1-6.1",
                 bands = c("NDVI", "EVI"),
                 roi = sf_roi,
                 start_date = "2018-09-01",
@@ -225,6 +247,11 @@ test_that("Retrieving points from BDC using POINT shapefiles", {
         object = unique(points_cf[["end_date"]]),
         expected = as.Date(cube_timeline[length(cube_timeline)])
     )
+    expect_true(
+        all(
+            c("sits", "tbl_df", "tbl", "data.frame") %in% class(points_cf)
+        )
+    )
 
     points_bbox <- .bbox(sf_cf)
 
@@ -244,7 +271,7 @@ test_that("Retrieving points from BDC using sits tibble", {
         {
             sits_cube(
                 source = "BDC",
-                collection = "MOD13Q1-6",
+                collection = "MOD13Q1-6.1",
                 bands = c("NDVI", "EVI"),
                 roi = cube_bbox,
                 start_date = "2018-09-01",
@@ -255,7 +282,7 @@ test_that("Retrieving points from BDC using sits tibble", {
         .default = NULL
     )
     testthat::skip_if(purrr::is_null(modis_cube),
-        message = "BDC is not accessible"
+        message = "MPC is not accessible"
     )
     # create a sits_tibble to retrieve the data
     # first select unique locations
@@ -266,8 +293,8 @@ test_that("Retrieving points from BDC using sits tibble", {
         .data[["label"]]
     )
     input_tb <- cerrado_pts[1:5, ]
-    input_tb$start_date <- as.Date("2018-09-01")
-    input_tb$end_date <- as.Date("2019-08-29")
+    input_tb$start_date <- as.Date("2018-08-22")
+    input_tb$end_date <- as.Date("2019-08-30")
     points_tb <- sits_get_data(modis_cube,
         samples = input_tb,
         progress = FALSE
@@ -282,6 +309,11 @@ test_that("Retrieving points from BDC using sits tibble", {
         object = unique(points_tb[["end_date"]]),
         expected = as.Date(cube_timeline[length(cube_timeline)])
     )
+    expect_true(
+        all(
+            c("sits", "tbl_df", "tbl", "data.frame") %in% class(points_tb)
+        )
+    )
 })
 
 test_that("Retrieving points from BDC using sf objects", {
@@ -299,7 +331,7 @@ test_that("Retrieving points from BDC using sf objects", {
         {
             sits_cube(
                 source = "BDC",
-                collection = "MOD13Q1-6",
+                collection = "MOD13Q1-6.1",
                 bands = c("NDVI", "EVI"),
                 roi = sf_roi,
                 start_date = "2018-09-01",
@@ -311,7 +343,7 @@ test_that("Retrieving points from BDC using sf objects", {
     )
 
     testthat::skip_if(purrr::is_null(modis_cube),
-        message = "BDC is not accessible"
+        message = "MPC is not accessible"
     )
     points_cf <- sits_get_data(modis_cube,
         samples = sf_cf[1:5, ],
@@ -329,6 +361,11 @@ test_that("Retrieving points from BDC using sf objects", {
         object = unique(points_cf[["end_date"]]),
         expected = as.Date(cube_timeline[length(cube_timeline)])
     )
+    expect_true(
+        all(
+            c("sits", "tbl_df", "tbl", "data.frame") %in% class(points_cf)
+        )
+    )
 
     points_bbox <- .bbox(sf_cf)
 
@@ -354,7 +391,7 @@ test_that("Retrieving points from BDC using sf objects", {
         {
             sits_cube(
                 source = "BDC",
-                collection = "MOD13Q1-6",
+                collection = "MOD13Q1-6.1",
                 bands = c("NDVI", "EVI"),
                 roi = sf_mt,
                 start_date = "2018-09-01",
@@ -385,10 +422,14 @@ test_that("Retrieving points from BDC using sf objects", {
         object = unique(points_poly[["end_date"]]),
         expected = as.Date(cube_timeline[length(cube_timeline)])
     )
+    expect_true(
+        all(
+            c("sits", "tbl_df", "tbl", "data.frame") %in% class(points_poly)
+        )
+    )
 
     # test bounding box
     polygons_bbox <- .bbox(sf_mt)
-
     points_poly_in_bbox <- dplyr::filter(
         points_poly,
         .data[["longitude"]] >= polygons_bbox[["xmin"]],
@@ -400,6 +441,89 @@ test_that("Retrieving points from BDC using sf objects", {
     expect_true(nrow(points_poly_in_bbox) == nrow(points_poly))
 })
 
+test_that("Retrieving points from MPC Base Cube", {
+    regdir <- paste0(tempdir(), "/base_cube_reg/")
+    if (!dir.exists(regdir)) {
+        suppressWarnings(dir.create(regdir))
+    }
+    # define roi
+    roi <- list(
+        lon_min = -55.69004,
+        lon_max = -55.62223,
+        lat_min = -11.78788,
+        lat_max = -11.73343
+    )
+    # load sentinel-2 cube
+    s2_cube <- sits_cube(
+        source     = "MPC",
+        collection = "SENTINEL-2-L2A",
+        start_date = "2019-01-01",
+        end_date = "2019-01-20",
+        bands = c("B05"),
+        tiles = "21LXH",
+        progress = FALSE
+    )
+    s2_cube <- suppressWarnings(sits_regularize(
+        cube = s2_cube,
+        period = "P16D",
+        res = 320,
+        multicores = 1,
+        tiles = "21LXH",
+        output_dir = regdir,
+        progress = FALSE
+    ))
+    # load dem cube
+    dem_cube <- sits_cube(
+        source = "MPC",
+        collection = "COP-DEM-GLO-30",
+        tiles = "21LXH"
+    )
+    dem_cube <- sits_regularize(
+        cube = dem_cube,
+        multicores = 1,
+        res = 232,
+        tiles = "21LXH",
+        output_dir = regdir
+    )
+    # create base cube
+    base_cube <- sits_add_base_cube(s2_cube, dem_cube)
+    # load samples
+    samples <- read.csv(
+        system.file("extdata/samples/samples_sinop_crop.csv", package = "sits")
+    )
+    # edit samples to work with the cube (test purposes only)
+    samples[["start_date"]] <- "2019-01-02"
+    samples[["end_date"]] <- "2019-01-02"
+    # extract data
+    samples_ts <- sits_get_data(
+        base_cube,
+        samples = samples,
+        crs = 32721,
+        multicores = 1
+    )
+    # validations
+    cube_timeline <- sits_timeline(base_cube)
+    expect_equal(object = nrow(samples_ts), expected = 18)
+    expect_equal(
+        object = unique(samples_ts[["start_date"]]),
+        expected = as.Date(cube_timeline[1])
+    )
+    expect_equal(
+        object = unique(samples_ts[["end_date"]]),
+        expected = as.Date(cube_timeline[length(cube_timeline)])
+    )
+    expect_true(
+        all(
+            c("sits_base", "sits", "tbl_df", "tbl", "data.frame") %in%
+                class(samples_ts)
+        )
+    )
+
+    unlink(s2_cube[["file_info"]][[1]]$path)
+    unlink(dem_cube[["file_info"]][[1]]$path)
+    unlink(base_cube[["file_info"]][[1]]$path)
+})
+
 test_that("Reading metadata from CSV file", {
     csv_file <- paste0(tempdir(), "/cerrado_2classes.csv")
     sits_to_csv(cerrado_2classes, file = csv_file)
@@ -440,7 +564,7 @@ test_that("Reading data from Classified data", {
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
     cube <- sits_cube(
         source = "BDC",
-        collection = "MOD13Q1-6",
+        collection = "MOD13Q1-6.1",
         data_dir = data_dir,
         progress = FALSE
     )
@@ -476,7 +600,12 @@ test_that("Reading data from Classified data", {
     expect_equal(
         nrow(points_poly), nrow(read.csv(csv_raster_file))
     )
-
+    expect_true(
+        all(
+            c("predicted", "sits", "tbl_df", "tbl", "data.frame") %in%
+                class(points_poly)
+        )
+    )
     expect_equal(
         colnames(points_poly), c(
             "longitude", "latitude",
@@ -501,3 +630,54 @@ test_that("Reading data from Classified data", {
     unlink(bayes_cube$file_info[[1]]$path)
     unlink(label_cube$file_info[[1]]$path)
 })
+
+test_that("Reading data from Classified data from STAC", {
+    roi <- c("lon_min" = -55.80259,  "lon_max" = -55.19900,
+             "lat_min" = -11.80208, "lat_max" = -11.49583)
+
+    # load cube from stac
+    class_cube <- .try(
+        {
+            sits_cube(
+                source     = "TERRASCOPE",
+                collection = "WORLD-COVER-2021",
+                roi        = roi,
+                progress   = FALSE
+            )
+        },
+        .default = NULL
+    )
+
+    testthat::skip_if(purrr::is_null(class_cube),
+                      message = "TERRASCOPE is not accessible"
+    )
+
+    # adapt date to work with the sinop samples
+    class_cube[["file_info"]][[1]][["start_date"]] <- "2013-10-01"
+    class_cube[["file_info"]][[1]][["end_date"]] <- "2013-10-01"
+    # Using CSV
+    csv_raster_file <- system.file("extdata/samples/samples_sinop_crop.csv",
+                                   package = "sits"
+    )
+    points_poly <- suppressWarnings(
+        sits_get_data(class_cube,
+                      samples = csv_raster_file,
+                      progress = TRUE,
+                      multicores = 1
+        )
+    )
+    expect_equal(nrow(points_poly), 5)
+    expect_equal(
+        colnames(points_poly), c(
+            "longitude", "latitude",
+            "start_date", "end_date",
+            "label", "cube", "predicted"
+        )
+    )
+    expect_true(
+        all(
+            c("predicted", "sits", "tbl_df", "tbl", "data.frame") %in%
+                class(points_poly)
+        )
+    )
+})
