@@ -166,31 +166,6 @@ test_that("DL-MLP", {
     expect_null(stats)
 })
 
-test_that("ResNet", {
-    model <- tryCatch(
-        {
-            sits_train(samples_modis_ndvi, sits_resnet(epochs = 5))
-        },
-        error = function(e) {
-            return(NULL)
-        }
-    )
-    if (purrr::is_null(model)) {
-        skip("ResNet model not working")
-    }
-
-    point_ndvi <- sits_select(point_mt_6bands, bands = "NDVI")
-    point_class <- sits_classify(
-        data = point_ndvi,
-        ml_model = model,
-        progress = FALSE
-    )
-
-    expect_true(all(point_class$predicted[[1]]$class %in%
-        sits_labels(samples_modis_ndvi)))
-    expect_true(nrow(sits_show_prediction(point_class)) == 17)
-})
-
 test_that("TempCNN model", {
     model <- sits_train(
         samples_modis_ndvi,
