@@ -13,7 +13,7 @@ test_that("View", {
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
     modis_cube <- sits_cube(
         source = "BDC",
-        collection = "MOD13Q1-6",
+        collection = "MOD13Q1-6.1",
         data_dir = data_dir,
         progress = FALSE
     )
@@ -102,8 +102,6 @@ test_that("View", {
     expect_true(grepl("EPSG3857", v6$x$options$crs$crsClass))
     expect_equal(v6$x$calls[[1]]$method, "addProviderTiles")
     expect_equal(v6$x$calls[[1]]$args[[1]], "GeoportailFrance.orthos")
-    expect_equal(v6$x$calls[[5]]$args[[5]], "012010 entropy")
-    expect_equal(v6$x$calls[[6]]$args[[5]], "classification")
 
     # segmentation
     # segment the image
@@ -125,12 +123,6 @@ test_that("View", {
     expect_equal(v7$x$calls[[1]]$args[[1]], "GeoportailFrance.orthos")
     expect_equal(v7$x$calls[[5]]$method, "addRasterImage")
 
-    v8 <- sits_view(segments, band = "NDVI")
-    expect_true(grepl("EPSG3857", v8$x$options$crs$crsClass))
-    expect_identical(v8$x$calls[[1]]$method, "addProviderTiles")
-    expect_identical(v8$x$calls[[1]]$args[[1]], "GeoportailFrance.orthos")
-    expect_identical(v8$x$calls[[5]]$method, "addRasterImage")
-    expect_identical(v8$x$calls[[6]]$method, "addPolygons")
 
     probs_segs <- sits_classify(
         data = segments,
@@ -159,7 +151,42 @@ test_that("View", {
     expect_identical(v9$x$calls[[6]]$method, "addPolygons")
     expect_identical(v9$x$calls[[7]]$method, "addPolygons")
 
+    expect_true(all(file.remove(unlist(modis_uncert$file_info[[1]][["path"]]))))
+    expect_true(all(file.remove(unlist(modis_probs$file_info[[1]][["path"]]))))
+    expect_true(all(file.remove(unlist(modis_label$file_info[[1]][["path"]]))))
+})
 
+test_that("View class cube from STAC", {
+    cube_roi <- c("lon_min" = -62.7,  "lon_max" = -62.5,
+                  "lat_min" = -8.83 , "lat_max" = -8.70)
+
+    # load cube from stac
+    to_class <- sits_cube(
+        source     = "TERRASCOPE",
+        collection = "WORLD-COVER-2021",
+        roi        = cube_roi,
+        progress   = FALSE
+    )
+    testthat::skip_if(purrr::is_null(to_class),
+                      message = "TERRASCOPE is not accessible"
+    )
+    v1 <- sits_view(to_class)
+    expect_true("leaflet" %in% class(v1))
+
+    # view with dates
+    timeline <- sits_timeline(to_class)
+
+    # view the data cube
+    v2 <- sits_view(to_class,
+                    band = "CLASS",
+                    dates = timeline[[1]],
+                    palette = "RdYlGn"
+    )
+    expect_true("leaflet" %in% class(v2))
+    expect_true(grepl("EPSG3857", v2$x$options$crs$crsClass))
+})
+
+test_that("View BDC cube",{
     cbers_cube <- tryCatch(
         {
             sits_cube(
@@ -181,21 +208,17 @@ test_that("View", {
                       message = "BDC is not accessible"
     )
     v_cb <- sits_view(cbers_cube,
-                    tiles = c("007004", "007005"),
-                    red = "B15",
-                    green = "B16",
-                    blue = "B13",
-                    dates = "2018-08-29")
+                      tiles = c("007004", "007005"),
+                      red = "B15",
+                      green = "B16",
+                      blue = "B13",
+                      dates = "2018-08-29")
 
     expect_identical(v_cb$x$options$crs$crsClass, "L.CRS.EPSG3857")
     expect_identical(v_cb$x$calls[[1]]$args[[1]], "GeoportailFrance.orthos")
     expect_identical(v_cb$x$calls[[5]]$method, "addRasterImage")
-    expect_identical(v_cb$x$calls[[6]]$args[[5]], "007005 2018-08-29")
-
-    expect_true(all(file.remove(unlist(modis_uncert$file_info[[1]][["path"]]))))
-    expect_true(all(file.remove(unlist(modis_probs$file_info[[1]][["path"]]))))
-    expect_true(all(file.remove(unlist(modis_label$file_info[[1]][["path"]]))))
 })
+
 test_that("View SOM map", {
     set.seed(2903)
     expect_warning({
